<?php
/**
 * @var User $logged_in_user
 */

try {
    require_once __DIR__ . "/../includes/ajax_protect.php";
    require_once __DIR__ . "/../includes/login.php";

    if (isset($_FILES['file']['tmp_name']) && is_uploaded_file($_FILES['file']['tmp_name'])) {
        if (isset($_POST["devices"]) && is_array($_POST["devices"])) {
            require_once __DIR__ . "/../includes/read-excel.php";
            $messages = array();
            $requiredColumns = 1;
            $attachments = $logged_in_user->upload("attachments");
            $attachments = count($attachments) > 0 ? implode(',', $attachments) : null;
            if (empty($_POST["message"])) {
                $requiredColumns = 2;
            }
            foreach ($spreadsheet->getAllSheets() as $sheet) {
                $data = $sheet->toArray();
                $headers = $data[0];
                array_walk_recursive($headers, 'sanitizeByReference');
                foreach ($data as $row) {
                    if (count($row) >= $requiredColumns) {
                        $number = sanitize($row[0]);
                        if (isValidMobileNumber($number)) {
                            if (empty($_POST["message"])) {
                                if (trim($row[1]) !== '') {
                                    array_push($messages, array("number" => $number, "message" => $row[1], "attachments" => $attachments, 'type' => $_POST["type"]));
                                }
                            } else {
                                $message = $_POST["message"];
                                for ($i = 0; $i < count($row); $i++) {
                                    $currentColumn = sanitize($row[$i]);
                                    $columnNumber = $i + 1;
                                    $header = $headers[$i];
                                    if (empty($currentColumn)) {
                                        $message = str_ireplace("%{$header}%", "", $message);
                                        $message = str_ireplace("%col-{$columnNumber}%", "", $message);
                                    } else {
                                        $message = str_ireplace("%{$header}%", $currentColumn, $message);
                                        $message = str_ireplace("%col-{$columnNumber}%", $currentColumn, $message);
                                    }
                                }
                                array_push($messages, array("number" => $number, "message" => $message, "attachments" => $attachments, 'type' => $_POST["type"]));
                            }
                        }
                    }
                }
            }
            $messagesCount = count($messages);
            if ($messagesCount > 0) {
                $schedule = null;
                if (isset($_POST["schedule"])) {
                    $schedule = new DateTime($_POST["schedule"], new DateTimeZone($_SESSION["timeZone"]));
                    $schedule = $schedule->getTimestamp();
                }
                Message::sendMessages($messages, $logged_in_user, $_POST["devices"], $schedule);
                if (is_null($schedule)) {
                    $success = $messagesCount > 1 ? __("success_messages_sent", ["count" => $messagesCount]) : __("success_message_sent", ["count" => $messagesCount]);
                } else {
                    $success = $messagesCount > 1 ? __("success_messages_scheduled", ["count" => $messagesCount]) : __("success_message_scheduled", ["count" => $messagesCount]);
                }
                echo json_encode(array(
                    'result' => $success
                ));
            } else {
                throw new Exception(__("error_no_messages_found"));
            }
        } else {
            throw new Exception(__("error_no_device_selected"));
        }
    } else {
        throw new Exception(__("error_uploading_excel_file"));
    }
} catch (Throwable $t) {
    echo json_encode(array(
        'error' => $t->getMessage()
    ));
} catch (Exception $e) {
    echo json_encode(
        array("error" => $e->getMessage())
    );
} finally {
    if (isset($fileName) && file_exists($fileName)) {
        unlink($fileName);
    }
}