<?php

class Message extends Entity implements JsonSerializable
{
    public $number;

    public $message;

    public $deviceID;

    public $simSlot;

    public $schedule;

    public $userID;

    public $groupID;

    public $status;

    public $resultCode;

    public $errorCode;

    public $type;

    public $attachments;

    public $retries;

    public $sentDate;

    public $deliveredDate;

    public $expiryDate;

    /**
     * @return string
     */
    public function getNumber()
    {
        return $this->number;
    }

    /**
     * @param string $number
     */
    public function setNumber($number)
    {
        $this->number = $number;
    }

    /**
     * @return string
     */
    public function getMessage()
    {
        return $this->message;
    }

    /**
     * @param string $message
     */
    public function setMessage($message)
    {
        $this->message = $message;
    }

    /**
     * @return string
     */
    public function getResultCode()
    {
        if ($this->getType() === "sms") {
            if (isset($this->resultCode)) {
                switch ($this->resultCode) {
                    case -1:
                        return null;
                    case 0:
                        return "DELIVERY_FAILURE";
                    case 1:
                        if (is_null($this->getErrorCode()) || $this->getErrorCode() == -1) {
                            return "GENERIC_FAILURE";
                        } else {
                            return "GENERIC_FAILURE [{$this->errorCode}]";
                        }
                    case 2:
                        return "RADIO_OFF";
                    case 3:
                        return "NULL_PDU";
                    case 4:
                        return "NO_SERVICE";
                    case 5:
                        return "LIMIT_EXCEEDED";
                    case 7:
                        return "SHORT_CODE_NOT_ALLOWED";
                    case 8:
                        return "SHORT_CODE_NEVER_ALLOWED";
                }
                return "UNKNOWN_ERROR [{$this->resultCode}]";
            }
        } else {
            return null;
        }
        return $this->resultCode;
    }

    /**
     * @param int $resultCode
     */
    public function setResultCode($resultCode)
    {
        $this->resultCode = $resultCode;
    }

    /**
     * @return int
     */
    public function getErrorCode()
    {
        return $this->errorCode;
    }

    /**
     * @param int $errorCode
     */
    public function setErrorCode($errorCode)
    {
        $this->errorCode = $errorCode;
    }


    /**
     * @return string
     */
    public function getType()
    {
        return $this->type;
    }

    /**
     * @param string $type
     */
    public function setType($type)
    {
        $this->type = $type;
    }

    /**
     * @return array
     */
    public function getAttachments()
    {
        if (empty($this->attachments)) {
            return [];
        }
        return explode(',', $this->attachments);
    }

    /**
     * @param string $attachments
     */
    public function setAttachments($attachments)
    {
        $this->attachments = $attachments;
    }

    /**
     * @return string
     */
    public function getStatus()
    {
        return $this->status;
    }

    /**
     * @param string $status
     */
    public function setStatus($status)
    {
        $this->status = $status;
    }

    /**
     * @return DateTime
     */
    public function getSentDate()
    {
        return getDisplayTime($this->sentDate);
    }

    /**
     * @param string $sentDate
     */
    public function setSentDate($sentDate)
    {
        $this->sentDate = $sentDate;
    }

    /**
     * @return DateTime|null
     */
    public function getDeliveredDate()
    {
        if (isset($this->deliveredDate)) {
            return getDisplayTime($this->deliveredDate);
        }
        return null;
    }

    /**
     * @param string $deliveredDate
     */
    public function setDeliveredDate($deliveredDate)
    {
        $this->deliveredDate = $deliveredDate;
    }

    /**
     * @return DateTime|null
     * @throws Exception
     */
    public function getExpiryDate()
    {
        if (isset($this->expiryDate)) {
            return new DateTime($this->expiryDate);
        }
        return null;
    }

    /**
     * @param string $expiryDate
     */
    public function setExpiryDate($expiryDate)
    {
        $this->expiryDate = $expiryDate;
    }

    /**
     * @return int
     */
    public function getDeviceID()
    {
        return $this->deviceID;
    }

    /**
     * @param int $deviceID
     */
    public function setDeviceID($deviceID)
    {
        $this->deviceID = $deviceID;
    }

    /**
     * @return int
     */
    public function getUserID()
    {
        return $this->userID;
    }

    /**
     * @param int $userID
     */
    public function setUserID($userID)
    {
        $this->userID = $userID;
    }

    /**
     * @return string
     */
    public function getGroupID()
    {
        return $this->groupID;
    }

    /**
     * @param string $groupID
     */
    public function setGroupID($groupID)
    {
        $this->groupID = $groupID;
    }

    /**
     * @return int
     */
    public function getSimSlot()
    {
        return $this->simSlot;
    }

    /**
     * @param int $simSlot
     */
    public function setSimSlot($simSlot)
    {
        $this->simSlot = $simSlot;
    }

    /**
     * @return DateTime
     * @throws Exception
     */
    public function getSchedule()
    {
        if (isset($this->schedule)) {
            return DateTime::createFromFormat("U", $this->schedule)
                ->setTimezone(new DateTimeZone($_SESSION['timeZone']));
        }
        return null;
    }

    /**
     * @param int $schedule
     */
    public function setSchedule($schedule)
    {
        $this->schedule = $schedule;
    }

    /**
     * @return int
     */
    public function getRetries()
    {
        return (int)$this->retries;
    }

    /**
     * @param int $retries
     */
    public function setRetries($retries)
    {
        $this->retries = $retries;
    }

    public static function getErrorDescription($error) {
        $errors = [
            "NO_SERVICE" => "Your device simply has no cell reception. You're probably in the middle of nowhere, somewhere inside, underground, or up in space. Certainly away from any cell phone tower. Sometimes it also happens when you get a call while sending messages.",
            "RADIO_OFF" => "You switched your device into airplane mode, which tells your device exactly \"turn all radios off\" (cell, wifi, Bluetooth, NFC, ...).",
            "LIMIT_EXCEEDED" => "Failed because the phone reached the sending queue limit. Try setting the higher delay between messages from Profile page.",
            "GENERIC_FAILURE" => "Something went wrong and there's no way to tell what, why or how. You have to provide the mobile number in E.164 formatting (e.g. +911234567890, +14155552671). You can also try setting the higher delay between messages from Profile page.",
            "GENERIC_FAILURE [1]" => "This cause indicates that the destination requested by the Mobile Station cannot be reached because, although the number is in a valid format, it is not currently assigned (allocated).",
            "GENERIC_FAILURE [8]" => "This cause indicates that the MS has tried to send a mobile originating short message when the MS’s network operator or service provider has forbidden such transactions.",
            "GENERIC_FAILURE [10]" => "This cause indicates that the outgoing call barred service applies to the short message service for the called destination.",
            "GENERIC_FAILURE [17]" => "This cause is sent to the MS if the MSC cannot service an MS generated request because of PLMN failures, e.g. problems in MAP.",
            "GENERIC_FAILURE [21]" => "This cause indicates that the equipment sending this cause does not wish to accept this short message, although it could have accepted the short message since the equipment sending this cause is neither busy nor incompatible.",
            "GENERIC_FAILURE [27]" => "This cause indicates that the destination indicated by the Mobile Station cannot be reached because the interface to the destination is not functioning correctly. The term “not functioning correctly” indicates that a signaling message was unable to be delivered to the remote user; e.g., a physical layer or data link layer failure at the remote user, user equipment off-line, etc.",
            "GENERIC_FAILURE [28]" => "This cause indicates that the subscriber is not registered in the PLMN (i.e. IMSI not known).",
            "GENERIC_FAILURE [29]" => "This cause indicates that the facility requested by the Mobile Station is not supported by the PLMN.",
            "GENERIC_FAILURE [30]" => "This cause indicates that the subscriber is not registered in the HLR (i.e. IMSI or directory number is not allocated to a subscriber).",
            "GENERIC_FAILURE [38]" => "This cause indicates that the network is not functioning correctly and that the condition is likely to last a relatively long period of time; e.g., immediately reattempting the short message transfer is not likely to be successful.",
            "GENERIC_FAILURE [41]" => "This cause indicates that the network is not functioning correctly and that the condition is not likely to last a long period of time; e.g., the Mobile Station may wish to try another short message transfer attempt almost immediately.",
            "GENERIC_FAILURE [42]" => "This cause indicates that the short message service cannot be serviced because of high traffic.",
            "GENERIC_FAILURE [47]" => "Resources unavailable. This cause is used to report a resource unavailable event only when no other cause applies.",
            "GENERIC_FAILURE [50]" => "This cause indicates that the requested short message service could not be provided by the network because the user has not completed the necessary administrative arrangements with its supporting networks.",
            "GENERIC_FAILURE [69]" => "This cause indicates that the network is unable to provide the requested short message service.",
            "GENERIC_FAILURE [81]" => "This cause indicates that the equipment sending this cause has received a message with a short message reference which is not currently in use on the MS-network interface.",
            "GENERIC_FAILURE [95]" => "This cause is used to report an invalid message event only when no other cause in the invalid message class applies.",
            "GENERIC_FAILURE [96]" => "This cause indicates that the equipment sending this cause has received a message where a mandatory information element is missing and/or has a content error (the two cases are indistinguishable).",
            "GENERIC_FAILURE [97]" => "This cause indicates that the equipment sending this cause has received a message with a message type it does not recognize either because this is a message not defined or defined but not implemented by the equipment sending this cause.",
            "GENERIC_FAILURE [98]" => "Message not compatible with short message protocol state",
            "GENERIC_FAILURE [99]" => "This cause indicates that the equipment sending this cause has received a message which includes information elements not recognized because the information element identifier is not defined or it is defined but not implemented by the equipment sending the cause. However, the information element is not required to be present in the message in order for the equipment to send the cause to process the message.",
            "GENERIC_FAILURE [111]" => "This cause is used to report a protocol error event only when no other cause applies.",
            "GENERIC_FAILURE [127]" => "This cause indicates that there has been interworking with a network that does not provide causes for actions it takes; thus, the precise cause for a message which is being sent cannot be ascertained.",
            "GENERIC_FAILURE [128]" => "Telematic internetworking not supported",
            "GENERIC_FAILURE [129]" => "Short message type 0 not supported",
            "GENERIC_FAILURE [130]" => "Cannot replace short message",
            "GENERIC_FAILURE [143]" => "Unspecified TP-PID error",
            "GENERIC_FAILURE [144]" => "Data code scheme not supported",
            "GENERIC_FAILURE [145]" => "Message class not supported",
            "GENERIC_FAILURE [159]" => "Unspecified TP-DCS error",
            "GENERIC_FAILURE [160]" => "Command cannot be actioned",
            "GENERIC_FAILURE [161]" => "Command unsupported",
            "GENERIC_FAILURE [175]" => "Unspecified TP-Command error",
            "GENERIC_FAILURE [176]" => "&nbsp;TPDU not supported",
            "GENERIC_FAILURE [192]" => "SC busy",
            "GENERIC_FAILURE [193]" => "No SC subscription",
            "GENERIC_FAILURE [194]" => "SC System failure",
            "GENERIC_FAILURE [195]" => "Invalid SME address",
            "GENERIC_FAILURE [196]" => "Destination SME barred",
            "GENERIC_FAILURE [197]" => "SM Rejected-Duplicate SM",
            "GENERIC_FAILURE [198]" => "TP-VPF not supported",
            "GENERIC_FAILURE [199]" => "TP-VP not supported",
            "GENERIC_FAILURE [208]" => "D0 SIM SMS Storage full",
            "GENERIC_FAILURE [209]" => "No SMS Storage capability in SIM",
            "GENERIC_FAILURE [210]" => "Error in MS",
            "GENERIC_FAILURE [211]" => "Memory capacity exceeded",
            "GENERIC_FAILURE [212]" => "Sim application toolkit busy",
            "GENERIC_FAILURE [213]" => "SIM data download error",
            "GENERIC_FAILURE [255]" => "Unspecified error cause",
            "GENERIC_FAILURE [300]" => "ME Failure",
            "GENERIC_FAILURE [301]" => "SMS service of ME reserved",
            "GENERIC_FAILURE [302]" => "Operation not allowed",
            "GENERIC_FAILURE [303]" => "Operation not supported",
            "GENERIC_FAILURE [304]" => "Invalid PDU mode parameter",
            "GENERIC_FAILURE [305]" => "Invalid Text mode parameter",
            "GENERIC_FAILURE [310]" => "SIM not inserted",
            "GENERIC_FAILURE [311]" => "SIM PIN required",
            "GENERIC_FAILURE [312]" => "PH-SIM PIN required",
            "GENERIC_FAILURE [313]" => "SIM failure",
            "GENERIC_FAILURE [314]" => "SIM busy",
            "GENERIC_FAILURE [315]" => "SIM wrong",
            "GENERIC_FAILURE [316]" => "SIM PUK required",
            "GENERIC_FAILURE [317]" => "SIM PIN2 required",
            "GENERIC_FAILURE [318]" => "SIM PUK2 required",
            "GENERIC_FAILURE [320]" => "Memory failure",
            "GENERIC_FAILURE [321]" => "Invalid memory index",
            "GENERIC_FAILURE [322]" => "Memory full",
            "GENERIC_FAILURE [330]" => "SMSC address unknown",
            "GENERIC_FAILURE [331]" => "No network service",
            "GENERIC_FAILURE [332]" => "Network timeout",
            "GENERIC_FAILURE [340]" => "No +CNMA expected",
            "GENERIC_FAILURE [500]" => "Unknown error",
            "GENERIC_FAILURE [512]" => "User abort",
            "GENERIC_FAILURE [513]" => "Unable to store",
            "GENERIC_FAILURE [514]" => "Invalid Status",
            "GENERIC_FAILURE [515]" => "Device busy or Invalid Character in string",
            "GENERIC_FAILURE [516]" => "Invalid length",
            "GENERIC_FAILURE [517]" => "Invalid character in PDU",
            "GENERIC_FAILURE [518]" => "Invalid parameter",
            "GENERIC_FAILURE [519]" => "Invalid length or character",
            "GENERIC_FAILURE [520]" => "Invalid character in text",
            "GENERIC_FAILURE [521]" => "Timer expired",
            "GENERIC_FAILURE [522]" => "Operation temporary not allowed",
            "GENERIC_FAILURE [532]" => "SIM not ready",
            "GENERIC_FAILURE [534]" => "Cell Broadcast error unknown",
            "GENERIC_FAILURE [535]" => "Protocol stack busy",
            "GENERIC_FAILURE [538]" => "Invalid parameter",
            "UNKNOWN_ERROR [*]" => "Something went wrong and there's no way to tell what, why, or how."
        ];
        if (array_key_exists($error, $errors)) {
            return $errors[$error];
        } else {
            return false;
        }
    }

    /**
     * Specify data which should be serialized to JSON
     * @link http://php.net/manual/en/jsonserializable.jsonserialize.php
     * @return mixed data which can be serialized by <b>json_encode</b>,
     * which is a value of any type other than a resource.
     * @since 5.4.0
     */
    public function jsonSerialize()
    {
        $message = get_object_vars($this);
        $message["sentDate"] = $this->getSentDate()->format(DATE_ISO8601);
        $deliveredDate = $this->getDeliveredDate();
        if (isset($deliveredDate)) {
            $message["deliveredDate"] = $deliveredDate->format(DATE_ISO8601);
        }
        return $message;
    }

    /**
     * @param Message[] $messages
     * @param User $user
     * @param bool $checkRetries
     * @throws Exception
     */
    public static function resend($messages, $user, $checkRetries = false)
    {
        if ($user->getExpiryDate() !== null && new DateTime($user->getExpiryDate()) < new DateTime()) {
            throw new Exception(__("error_subscription_expired"));
        } else {
            $groups = [];
            foreach ($messages as $message) {
                if ($checkRetries) {
                    $maxRetries = Setting::get("max_retries") ? (int)Setting::get("max_retries") : 1;
                    if ($maxRetries <= $message->getRetries()) {
                        continue;
                    }
                }
                if (is_null($message->getDeviceID())) {
                    if ($user->getPrimaryDeviceID() == 0) {
                        throw new Exception(__("error_no_active_device_found"));
                    } else {
                        $message->setDeviceID($user->getPrimaryDeviceID());
                    }
                }
                $message->setSentDate(date("Y-m-d H:i:s"));
                $message->setDeliveredDate(null);
                $message->setResultCode(null);
                $message->setErrorCode(null);
                $message->setStatus("Pending");
                $message->setRetries($message->getRetries() + 1);
                if (array_key_exists($message->getDeviceID(), $groups)) {
                    $groupID = $groups[$message->getDeviceID()]["data"]["groupId"];
                } else {
                    $groupID = uniqid(random_str(18), true);
                    $device = User::getDevice($message->getDeviceID(), $user->getID());
                    $groups[$device->getID()] = ["device" => $device, "data" => ["groupId" => $groupID, "delay" => $user->getDelay(), "reportDelivery" => $user->getReportDelivery()]];
                }
                $message->setGroupID($groupID);
            }
            $testGroups = [];
            foreach ($groups as $deviceID => $group) {
                $group["data"] = [];
                $testGroups[$deviceID] = $group;
            }
            Device::processRequests($testGroups);
            MysqliDb::getInstance()->startTransaction();
            foreach ($messages as $message) {
                $message->save(false);
            }
            MysqliDb::getInstance()->commit();
            Device::processRequests($groups);
        }
    }

    /**
     * @param array $messages
     * @param User $user
     * @param array $devices
     * @param int $schedule
     * @return array
     * @throws Exception
     */
    public static function sendMessages($messages, $user, $devices = [], $schedule = null)
    {
        if ($user->getExpiryDate() !== null && new DateTime($user->getExpiryDate()) < new DateTime()) {
            throw new Exception(__("error_subscription_expired"));
        } else {
            if (isset($schedule) && $schedule <= time()) {
                throw new Exception(__("error_invalid_schedule_time"));
            }
            if (is_array($messages)) {
                $messagesCount = count($messages);
                if ($messagesCount > 0) {
                    $groups = array();
                    if (is_null($user->getCredits()) || $user->getCredits() >= $messagesCount) {
                        if (empty($devices)) {
                            if ($user->getPrimaryDeviceID() == 0) {
                                throw new Exception(__("error_no_active_device_found"));
                            } else {
                                $devices = [$user->getPrimaryDeviceID()];
                            }
                        }
                        $messagesChunks = partition($messages, count($devices));
                        $msgObjects = [];
                        $sims = $user->getSims();
                        for ($i = 0; $i < count($messagesChunks); $i++) {
                            $identifiers = Device::isValidIdentifier($devices[$i]);
                            if (empty($identifiers)) {
                                throw new Exception(__("error_invalid_request_format"));
                            }
                            if (!array_key_exists($identifiers[0], $groups)) {
                                $device = User::getDevice($identifiers[0], $user->getID());
                                $groups[$identifiers[0]] = ["device" => $device, "sims" => [], "data" => []];
                            }
                            if (isset($identifiers[1])) {
                                if (isset($sims[$identifiers[0]][$identifiers[1]])) {
                                    $groups[$identifiers[0]]["sims"][] = $identifiers[1];
                                } else {
                                    throw new Exception(__("error_no_sim_present", ["slot" => $identifiers[1]]));
                                }
                            }
                        }
                        Device::processRequests($groups);
                        MysqliDb::getInstance()->startTransaction();
                        $i = 0;
                        foreach (array_keys($groups) as $deviceID) {
                            $messagesChunksDevice = [];
                            $groupID = uniqid(random_str(18), true);
                            $groups[$deviceID]["data"] = ["groupId" => $groupID, "delay" => $user->getDelay(), "reportDelivery" => $user->getReportDelivery()];
                            if (!empty($groups[$deviceID]["sims"])) {
                                foreach ($groups[$deviceID]["sims"] as $simSlot) {
                                    $messagesChunksDevice[$simSlot] = $messagesChunks[$i];
                                    $i++;
                                }
                            } else {
                                $messagesChunksDevice[null] = $messagesChunks[$i];
                                $i++;
                            }
                            $groupMessagesCount = 0;
                            foreach ($messagesChunksDevice as $simSlotIndex => $messagesSim) {
                                foreach ($messagesSim as $message) {
                                    if (empty($message["number"]) || (!(isset($message["message"]) && trim($message["message"]) !== ''))) {
                                        throw new Exception(__("error_invalid_request_format"));
                                    } else {
                                        if (isValidMobileNumber($message["number"])) {
                                            $obj = new Message();
                                            $obj->setNumber($message["number"]);
                                            $obj->setMessage($message["message"]);
                                            if (is_null($schedule)) {
                                                $obj->setStatus("Pending");
                                            } else {
                                                $obj->setStatus("Scheduled");
                                                $obj->setSchedule($schedule);
                                            }
                                            if (isset($message["type"])) {
                                                $obj->setType($message["type"]);
                                                if (isset($message["attachments"]) && $message["type"] === "mms") {
                                                    $obj->setAttachments($message["attachments"]);
                                                }
                                            }
                                            $obj->setDeviceID($deviceID);
                                            $obj->setExpiryDate($user->getExpiryDate());
                                            $obj->setUserID($user->getID());
                                            $obj->setGroupID($groupID);
                                            if ($simSlotIndex !== "") {
                                                $obj->setSimSlot($simSlotIndex);
                                            }
                                            $obj->setSentDate(date("Y-m-d H:i:s"));
                                            $obj->save();
                                            $msgObjects[] = $obj;
                                            $groupMessagesCount++;
                                        } else {
                                            throw new Exception(__("error_use_valid_number"));
                                        }
                                    }
                                }
                            }
                            $groups[$deviceID]["count"] = $groupMessagesCount;
                        }
                        if (isset($schedule)) {
                            if (!is_null($user->getCredits())) {
                                $user->setCredits($user->getCredits() - count($messages));
                                $user->save();
                            }
                        }
                        MysqliDb::getInstance()->commit();
                        if (is_null($schedule)) {
                            Device::processRequests($groups, true);
                        }
                        if (Setting::get("pusher_enabled")) {
                            try {
                                $where = $user->getIsAdmin() ? "" : " WHERE Message.userID = {$user->getID()}";
                                $query = "SELECT COUNT(IF(Message.status = 'Scheduled', 1, NULL)) as totalScheduled, COUNT(IF(Message.status = 'Pending', 1, NULL)) as totalPending, COUNT(IF(Message.status = 'Queued', 1, NULL)) as totalQueued, deviceID FROM Message" . $where . " GROUP BY deviceID";
                                $counts = MysqliDb::getInstance()->rawQuery($query);
                                sendPusherNotification("user-{$user->getApiKey()}", "messages-queued", $counts);
                            } catch (Exception $e) { }
                        }
                        return $msgObjects;
                    } else {
                        throw new Exception(__("error_credits_depleted"));
                    }
                } else {
                    throw new Exception(__("error_zero_messages"));
                }
            } else {
                throw new Exception(__("error_invalid_request_format"));
            }
        }
    }

    /**
     * @param string $attachments
     * @return string
     * @throws Exception
     */
    public static function isValidAttachments($attachments)
    {
        $attachments = explode(',', $attachments);
        $result = "";
        foreach ($attachments as $attachment) {
            $attachment = trim($attachment);
            if ($attachment) {
                if (!filter_var($attachment, FILTER_VALIDATE_URL)) {
                    throw new Exception(__("attachments_invalid"));
                }
                if (!empty($result)) {
                    $result .= ",";
                }
                $result .= $attachment;
            }
        }
        return $result;
    }
}
