<?php

class Subscription extends Entity
{
    public $planID;

    public $expiryDate;

    public $subscribedDate;

    public $cyclesCompleted;

    public $status;

    public $userID;

    public $subscriptionID;

    public $paymentMethod;

    public $plan;

    public $user;

    public static $relations = [
        "Plan" => ["ID", "planID"],
        "User" => ["ID", "userID"]
    ];

    public function __construct()
    {
        $this->plan = new Plan();
        $this->user = new User();
    }

    /**
     * @return int
     */
    public function getPlanID()
    {
        return $this->planID;
    }

    /**
     * @param int $planID
     */
    public function setPlanID($planID)
    {
        $this->planID = $planID;
    }

    /**
     * @return DateTime
     */
    public function getExpiryDate()
    {
        return getDisplayTime($this->expiryDate);
    }

    /**
     * @param string $expiryDate
     */
    public function setExpiryDate($expiryDate)
    {
        $this->expiryDate = $expiryDate;
    }

    /**
     * @return DateTime
     */
    public function getSubscribedDate()
    {
        return getDisplayTime($this->subscribedDate);
    }

    /**
     * @param string $subscribedDate
     */
    public function setSubscribedDate($subscribedDate)
    {
        $this->subscribedDate = $subscribedDate;
    }

    /**
     * @return int
     */
    public function getCyclesCompleted()
    {
        return (int)$this->cyclesCompleted;
    }

    /**
     * @param int $cyclesCompleted
     */
    public function setCyclesCompleted($cyclesCompleted)
    {
        $this->cyclesCompleted = $cyclesCompleted;
    }

    /**
     * @return string
     */
    public function getSubscriptionID()
    {
        return $this->subscriptionID;
    }

    /**
     * @param string $subscriptionID
     */
    public function setSubscriptionID($subscriptionID)
    {
        $this->subscriptionID = $subscriptionID;
    }

    /**
     * @return string
     */
    public function getPaymentMethod()
    {
        return $this->paymentMethod;
    }

    /**
     * @param string $paymentMethod
     */
    public function setPaymentMethod($paymentMethod)
    {
        $this->paymentMethod = $paymentMethod;
    }

    /**
     * @return int
     */
    public function getUserID()
    {
        return $this->userID;
    }

    /**
     * @param int $userID
     */
    public function setUserID($userID)
    {
        $this->userID = $userID;
    }

    /**
     * @return string
     */
    public function getStatus()
    {
        return $this->status;
    }

    /**
     * @param string $status
     */
    public function setStatus($status)
    {
        $this->status = $status;
    }

    /**
     * @return Plan
     */
    public function getPlan()
    {
        return $this->plan;
    }

    /**
     * @param Plan $plan
     */
    public function setPlan($plan)
    {
        $this->plan = $plan;
    }

    /**
     * @return User
     */
    public function getUser()
    {
        return $this->user;
    }

    /**
     * @param User $user
     */
    public function setUser($user)
    {
        $this->user = $user;
    }

    /**
     * @throws Exception
     */
    public function cancel()
    {
        if ($this->getPaymentMethod() == "PayPal") {
            PayPal::cancelSubscription($this->getSubscriptionID(), "Don't need it anymore");
        }
        $this->setStatus("CANCELLED");
        $this->save();
    }

    /**
     * @param string $expiryDate
     * @throws Exception
     */
    public function renew($expiryDate)
    {
        $user = new User();
        $user->setID($this->getUserID());
        $user->read();
        $user->setCredits($this->getPlan()->getCredits());
        $user->changeDevicesLimit($this->getPlan()->getDevices());
        $user->changeContactLimit($this->getPlan()->getContacts());
        $user->setExpiryDate($expiryDate);
        $user->sendUpdatedLimitsEmail();
        $user->save(false);
    }
}