<?php

class User extends Entity
{
    public $name;

    public $email;

    public $password;

    public $isAdmin;

    public $primaryDeviceID;

    public $delay;

    public $dateAdded;

    public $lastLogin;

    public $devicesLimit;

    public $contactsLimit;

    public $apiKey;

    public $reportDelivery;

    public $autoRetry;

    public $language;

    public $credits;

    public $expiryDate;

    public $smsToEmail;

    public $timeZone;

    public $webHook;

    /**
     * @return string
     */
    public function getName()
    {
        return $this->name;
    }

    /**
     * @param string $name
     */
    public function setName($name)
    {
        $this->name = $name;
    }

    /**
     * @return string
     */
    public function getEmail()
    {
        return $this->email;
    }

    /**
     * @param string $email
     */
    public function setEmail($email)
    {
        $this->email = $email;
    }

    /**
     * @return mixed
     */
    public function getPrimaryDeviceID()
    {
        return $this->primaryDeviceID;
    }

    /**
     * @param mixed $primaryDeviceID
     */
    public function setPrimaryDeviceID($primaryDeviceID)
    {
        $this->primaryDeviceID = $primaryDeviceID;
    }

    /**
     * @return string
     */
    public function getPassword()
    {
        return $this->password;
    }

    /**
     * @param string $password
     */
    public function setPassword($password)
    {
        $this->password = password_hash($password, PASSWORD_DEFAULT, ['cost' => 12]);
    }

    /**
     * @return bool
     */
    public function getIsAdmin()
    {
        return $this->isAdmin;
    }

    /**
     * @param bool $isAdmin
     */
    public function setIsAdmin($isAdmin)
    {
        $this->isAdmin = $isAdmin;
    }

    /**
     * @return DateTime
     */
    public function getDateAdded()
    {
        return getDisplayTime($this->dateAdded);
    }

    /**
     * @param string $dateAdded
     */
    public function setDateAdded($dateAdded)
    {
        $this->dateAdded = $dateAdded;
    }

    /**
     * @return DateTime|null
     */
    public function getLastLogin()
    {
        if (isset($this->lastLogin)) {
            return getDisplayTime($this->lastLogin);
        }
        return null;
    }

    /**
     * @param string $lastLogin
     */
    public function setLastLogin($lastLogin)
    {
        $this->lastLogin = $lastLogin;
    }

    /**
     * @return int
     */
    public function getDelay()
    {
        return $this->delay;
    }

    /**
     * @param int $delay
     * @throws Exception
     */
    public function setDelay($delay)
    {
        self::isValidDelay($delay);
        $this->delay = $delay;
    }

    /**
     * @return int|null
     */
    public function getDevicesLimit()
    {
        if (isset($this->devicesLimit)) {
            return (int)$this->devicesLimit;
        }
        return null;
    }

    /**
     * @param int $devicesLimit
     */
    public function setDevicesLimit($devicesLimit)
    {
        $this->devicesLimit = $devicesLimit;
    }

    /**
     * @return int|null
     */
    public function getContactsLimit()
    {
        if (isset($this->contactsLimit)) {
            return (int)$this->contactsLimit;
        }
        return null;
    }

    /**
     * @param int $contactsLimit
     */
    public function setContactsLimit($contactsLimit)
    {
        $this->contactsLimit = $contactsLimit;
    }

    /**
     * @return string
     */
    public function getApiKey()
    {
        return $this->apiKey;
    }

    /**
     * @param string $apiKey
     */
    public function setApiKey($apiKey)
    {
        $this->apiKey = $apiKey;
    }

    /**
     * @return int
     */
    public function getReportDelivery()
    {
        return $this->reportDelivery;
    }

    /**
     * @param int $reportDelivery
     */
    public function setReportDelivery($reportDelivery)
    {
        $this->reportDelivery = $reportDelivery;
    }

    /**
     * @return int
     */
    public function getAutoRetry()
    {
        return $this->autoRetry;
    }

    /**
     * @param int $autoRetry
     */
    public function setAutoRetry($autoRetry)
    {
        $this->autoRetry = $autoRetry;
    }

    /**
     * @return int|null
     */
    public function getCredits()
    {
        if (isset($this->credits)) {
            return (int)$this->credits;
        }
        return null;
    }

    /**
     * @param int $credits
     */
    public function setCredits($credits)
    {
        $this->credits = $credits;
    }

    /**
     * @return string
     */
    public function getTimeZone()
    {
        return $this->timeZone;
    }

    /**
     * @param string $timeZone
     */
    public function setTimeZone($timeZone)
    {
        $this->timeZone = $timeZone;
    }

    /**
     * @return string
     */
    public function getWebHook()
    {
        return $this->webHook;
    }

    /**
     * @param string $webHook
     */
    public function setWebHook($webHook)
    {
        $this->webHook = $webHook;
    }

    /**
     * @return string
     */
    public function getExpiryDate()
    {
        return $this->expiryDate;
    }

    /**
     * @param string $expiryDate
     */
    public function setExpiryDate($expiryDate)
    {
        $this->expiryDate = $expiryDate;
    }

    /**
     * @return string
     */
    public function getLanguage()
    {
        return $this->language;
    }

    /**
     * @param string $language
     */
    public function setLanguage($language)
    {
        $this->language = $language;
    }

    /**
     * @return bool
     */
    public function getSmsToEmail()
    {
        return $this->smsToEmail;
    }

    /**
     * @param bool $smsToEmail
     */
    public function setSmsToEmail($smsToEmail)
    {
        $this->smsToEmail = $smsToEmail;
    }

    /**
     * @param bool $outputFile
     * @return string|void
     * @throws Exception
     */
    public function getQRCode($outputFile = false)
    {
        require_once __DIR__ . "/../includes/phpqrcode/qrlib.php";

        $outfile = false;

        if ($outputFile) {
            $random = random_str(4);
            $outfile = sys_get_temp_dir() . DIRECTORY_SEPARATOR . "qr-code-{$random}.png";
        }

        $credentials = [
            'server' => getServerURL(),
            'key' => $this->getApiKey()
        ];

        QRcode::png(json_encode($credentials), $outfile, QR_ECLEVEL_H, 4, 5);

        if ($outputFile) {
            $data = file_get_contents($outfile);
            if ($data !== false) {
                unlink($outfile);
                return $data;
            } else {
                ob_start();

                QRcode::png(json_encode($credentials), false, QR_ECLEVEL_H, 4, 5);

                return ob_get_clean();
            }
        }
    }

    /**
     * @param int $deviceID
     * @param int $userID
     * @return Device
     * @throws Exception
     */
    public static function getDevice($deviceID, $userID)
    {
        $device = Device::getById($deviceID, $userID);
        if ($device) {
            if ($device->getEnabled()) {
                return $device;
            } else {
                $deviceName = strval($device);
                if (session_status() == PHP_SESSION_NONE || (isset($_SESSION["userID"]) && $device->user->getID() == $_SESSION["userID"])) {
                    throw new Exception(__("error_unable_to_connect_user", ["device" => $deviceName]));
                } else {
                    throw new Exception(
                        __("error_unable_to_connect_other", ["user" => $device->user->getName(), "userEmail" => $device->user->getEmail(), "device" => $deviceName])
                    );
                }
            }
        } else {
            throw new Exception(__("error_device_not_found"));
        }
    }

    /**
     * @param string $email
     * @param string $password
     * @return bool|User
     * @throws Exception
     */
    public static function login($email, $password)
    {
        $user = new User();
        $user->setEmail($email);
        if ($user->read() && password_verify($password, $user->getPassword())) {
            return $user;
        } else {
            return false;
        }
    }

    /**
     * @param int $id
     * @return bool|User
     * @throws Exception
     */
    public static function getById($id)
    {
        $user = new User();
        $user->setID($id);
        return $user->read();
    }

    /**
     * @return User
     * @throws Exception
     */
    public static function getAdmin()
    {
        $admin = new User();
        $admin->setIsAdmin(true);
        $admin->read();
        return $admin;
    }

    /**
     * @return int
     * @throws Exception
     */
    public function isActiveDevicesLimitReached()
    {
        if ($this->getDevicesLimit() != null) {
            return Device::where("Device.userID", $this->getID())
                    ->where("Device.enabled", true)
                    ->count() >= $this->getDevicesLimit();
        } else {
            return false;
        }
    }

    /**
     * @return array
     * @throws Exception
     */
    public function getSims()
    {
        return Sim::getSims($this->getID());
    }

    /**
     * @param bool $onlyEnabled
     * @return Device[]
     * @throws Exception
     */
    public function getDevices($onlyEnabled = true)
    {
        $device = Device::where("Device.userID", $this->getID());
        if ($onlyEnabled) {
            $device->where("Device.enabled", true);
        }
        return $device->read_all(false);
    }

    /**
     * @param int $selectedDevice
     * @param bool $onlyEnabled
     * @throws Exception
     */
    public function generateDevicesList($selectedDevice, $onlyEnabled = true)
    {
        $devices = $this->getDevices($onlyEnabled);
        foreach ($devices as $device) {
            $selected = $selectedDevice == $device->getID();
            $value = $device->getID();
            $option = strval($device);
            createOption($option, $value, $selected);
        }
    }

    /**
     * @param int[] $selectedDevice
     * @param bool $onlyEnabled
     * @throws Exception
     */
    public function generateDeviceSimsList($selectedDevice, $onlyEnabled = true)
    {
        $devices = $this->getDevices($onlyEnabled);
        $sims = $this->getSims();
        foreach ($devices as $device) {
            $selected = in_array($device->getID(), $selectedDevice);
            if (isset($sims[$device->getID()]) && count($sims[$device->getID()]) > 1) {
                foreach ($sims[$device->getID()] as $simSlot => $simName) {
                    $value = $device->getID() . "|" . $simSlot;
                    $option = strval($device) . " | " . $simName;
                    createOption($option, $value, $selected);
                }
            } else {
                $value = $device->getID();
                $option = strval($device);
                createOption($option, $value, $selected);
            }
        }
    }

    /**
     * @param int $newLimit
     * @throws Exception
     */
    public function changeDevicesLimit($newLimit)
    {
        $oldLimit = $this->getDevicesLimit();
        $this->setDevicesLimit($newLimit);
        if ($newLimit != null) {
            if ($oldLimit == null || $oldLimit > $newLimit) {
                $userDevices = Device::where("userID", $this->getID())->where("enabled", true)->read_all();
                $userDevicesCount = count($userDevices);
                if ($userDevicesCount > $newLimit) {
                    $disableDevicesCount = $userDevicesCount - $newLimit;
                    for ($i = 0; $i < $disableDevicesCount; $i++) {
                        $userDevice = $userDevices[$i];
                        $userDevice->setEnabled(0);
                        $userDevice->save();
                    }
                }
            }
        }
    }


    /**
     * @param int $newLimit
     * @throws Exception
     */
    public function changeContactLimit($newLimit)
    {
        $oldLimit = $this->getContactsLimit();
        $this->setContactsLimit($newLimit);
        if ($newLimit != null) {
            if ($oldLimit == null || $oldLimit > $newLimit) {
                $userContacts = Contact::where("ContactsList.userID", $this->getID())->where("subscribed", true)->read_all();
                $userContactsCount = count($userContacts);
                if ($userContactsCount > $newLimit) {
                    $unsubscribeContactsCount = $userContactsCount - $newLimit;
                    for ($i = 0; $i < $unsubscribeContactsCount; $i++) {
                        $userContact = $userContacts[$i];
                        $userContact->delete();
                    }
                }
            }
        }
    }

    public function getLimits(&$devices, &$contacts, &$credits, &$expiryDate)
    {
        $devices = __("unlimited_devices");
        if ($this->getDevicesLimit() != null) {
            if ($this->getDevicesLimit() > 1) {
                $devices = "{$this->getDevicesLimit()} " . strtolower(__('devices'));
            } else if ($this->getDevicesLimit() == 1) {
                $devices = "1 " . strtolower(__("device"));
            }
        }
        $contacts = __("unlimited_contacts");
        if ($this->getContactsLimit() != null) {
            if ($this->getContactsLimit() > 1) {
                $contacts = "{$this->getContactsLimit()} " . strtolower(__('contacts'));
            } else if ($this->getContactsLimit() == 1) {
                $contacts = "1 " . __("contact");
            }
        }
        $credits = __("unlimited_credits");
        if ($this->getCredits() != null) {
            if ($this->getCredits() > 1) {
                $credits = "{$this->getCredits()} " . strtolower(__('credits'));
            } else if ($this->getCredits() == 1) {
                $credits = "1 " . __("credit");
            }
        }
        $expiryDate = is_null($this->getExpiryDate()) ? __("forever") : getDisplayTime($this->getExpiryDate())->format(DATE_RFC850);
    }

    public function sendUpdatedLimitsEmail()
    {
        try {
            global $currentLanguage;
            if ($this->getLanguage() != $currentLanguage) {
                $tempLanguage = setLanguage($this->getLanguage());
            }
            $admin = User::getAdmin();
            $from = array($admin->getEmail(), $admin->getName());
            $to = array($this->getEmail(), $this->getName());
            $subject = __("edit_user_subject", [
                "app" => __("application_title")
            ]);
            $this->getLimits($devices, $contacts, $credits, $expiryDate);
            $body = __("edit_user_email_body", [
                "app" => __("application_title"),
                "user" => $this->getName(),
                "admin" => $admin->getName(),
                "adminEmail" => $admin->getEmail(),
                "credits" => $credits,
                "expiryDate" => $expiryDate,
                "devices" => $devices,
                "contacts" => $contacts,
            ]);
            if (!empty($tempLanguage)) {
                setLanguage($currentLanguage);
            }
            sendEmail($from, $to, $subject, $body);
        } catch (Exception $e) {
        }
    }

    public function getContacts() {
        $contactObjects = Contact::where("ContactsList.userID", $this->getID())->read_all();
        $contacts = [];
        foreach ($contactObjects as $contactObject) {
            if (!empty($contactObject->getName())) {
                if (!isset($contacts[$contactObject->getNumber()])) {
                    $contacts[$contactObject->getNumber()] = $contactObject->getName();
                }
            }
        }
        return $contacts;
    }

    /**
     * @param string $fieldName
     * @param string[] $allowedExtensions
     * @return array
     * @throws Exception
     */
    public function upload($fieldName, $allowedExtensions = ['png', 'jpg', 'jpeg', 'gif']) {
        $attachments = [];
        if (isset($_FILES[$fieldName]['name'])) {
            $total = count($_FILES[$fieldName]['name']);
            for ($i = 0; $i < $total; $i++) {
                $tempPath = $_FILES[$fieldName]['tmp_name'][$i];
                if (is_uploaded_file($tempPath)) {
                    $file = $_FILES[$fieldName]['name'][$i];
                    $filename = random_str(4) . "-" . basename($file);
                    $fileExtension = strtolower(pathinfo($file, PATHINFO_EXTENSION));
                    if (!in_array($fileExtension, $allowedExtensions)) {
                        throw new Exception(__("error_blocked_file_extension"));
                    }
                    $uploadDirectory = __DIR__ . "/../uploads/{$this->getID()}";
                    if (is_dir($uploadDirectory) || mkdir($uploadDirectory, 0755, true)) {
                        if (move_uploaded_file($tempPath, "{$uploadDirectory}/{$filename}")) {
                            $encodedFileName = rawurlencode($filename);
                            $attachments[] = "uploads/{$this->getID()}/{$encodedFileName}";
                        } else {
                            throw new Exception(__("error_uploading_attachment"));
                        }
                    } else {
                        throw new Exception(__("error_creating_upload_directory"));
                    }
                }
            }
        }
        return $attachments;
    }

    /**
     * @param string $value
     * @throws Exception
     */
    public static function isValidDelay($value)
    {
        $delays = explode('-', $value);
        if (count($delays) <= 2) {
            foreach ($delays as $delay) {
                if (ctype_digit($delay)) {
                    if ($delay < 0 || $delay > 120) {
                        throw new Exception(__("error_delay_limit"));
                    }
                } else {
                    throw new Exception(__("error_delay_not_numeric"));
                }
            }
            if (count($delays) === 2) {
                if ($delays[1] < $delays[0]) {
                    throw new Exception(__("error_max_delay_smaller"));
                }
            }
        } else {
            throw new Exception(__("error_invalid_delay"));
        }
    }
}