<?php
/**
 * @var User $logged_in_user
 */

$time_start = microtime(true);

use GuzzleHttp\Client;
use GuzzleHttp\Exception\GuzzleException;

require_once __DIR__ . "/../config.php";
require_once __DIR__ . "/../vendor/autoload.php";
set_time_limit(20);

date_default_timezone_set(TIMEZONE);

try {
    if (isset($_POST["androidId"]) && isset($_POST["userId"]) && isset($_POST["messages"])) {
        MysqliDb::getInstance()->startTransaction();
        $device = new Device();
        $device->setAndroidID($_POST["androidId"]);
        $device->setUserID($_POST["userId"]);
        if ($device->read()) {
            $messages = json_decode($_POST["messages"], true);
            $messageObjects = [];
            if ($messages) {
                $sendMessages = [];
                $responses = Response::where('userID', $device->getUserID())
                    ->where("enabled", "1")
                    ->read_all();
                foreach ($messages as $msg) {
                    $message = new Message();
                    $message->setNumber($msg["number"]);
                    $message->setMessage($msg["message"]);
                    if (isset($msg["simSlot"]) && $msg["simSlot"] != -1) {
                        $message->setSimSlot($msg["simSlot"]);
                    }
                    $message->setDeviceID($device->getID());
                    $message->setUserID($_POST["userId"]);
                    if (isset($msg["sentDate"])) {
                        $sentDate = new DateTime($msg["sentDate"]);
                        $sentDate->setTimezone(new DateTimeZone(TIMEZONE));
                        $message->setSentDate($sentDate->format("Y-m-d H:i:s"));
                    }
                    $receivedDate = new DateTime($msg["receivedDate"]);
                    $receivedDate->setTimezone(new DateTimeZone(TIMEZONE));
                    $message->setDeliveredDate($receivedDate->format("Y-m-d H:i:s"));
                    $message->setStatus("Received");
                    $message->save();
                    $messageObjects[] = $message;
                    if (isValidMobileNumber($message->getNumber())) {
                        if (strtolower(substr($message->getMessage(), 0, 4)) === "stop") {
                            $parts = explode(" ", $message->getMessage());
                            if (count($parts) === 2 && ctype_digit($parts[1])) {
                                $contact = new Contact();
                                $contact->setNumber($message->getNumber());
                                $contact->setContactsListID($parts[1]);
                                if ($contact->read()) {
                                    $contact->setSubscribed(false);
                                    $contact->save();
                                    $sendMessages[] = [
                                        "number" => $message->getNumber(),
                                        "message" => __("success_unsubscribed")
                                    ];
                                }
                            }
                        }
                        foreach ($responses as $response) {
                            $result = $response->match($message->getMessage());
                            if ($result) {
                                $sendMessages[] = [
                                    "number" => $message->getNumber(),
                                    "message" => $response->getResponse()
                                ];
                            }
                        }
                    }
                }

                try {
                    if (Setting::get("pusher_enabled") || $device->getUser()->getSmsToEmail()) {
                        $contacts = $device->getUser()->getContacts();
                        $receivedMessages = [];
                        $simObjects = Sim::where("deviceID", $device->getID())->read_all();
                        $sims = [];
                        foreach ($simObjects as $simObj) {
                            $sims[$simObj->getSlot()] = strval($simObj);
                        }

                        foreach ($messageObjects as $message) {
                            $receivedMessages[] = [
                                "number" => isset($contacts[$message->getNumber()]) ? $contacts[$message->getNumber()] . " ({$message->getNumber()})" : $message->getNumber(),
                                "message" => $message->getMessage(),
                                "device" => strval($device),
                                "sim" => $message->getSimSlot() != null ? " ({$sims[$message->getSimSlot()]})" : ""
                            ];
                        }

                        if (Setting::get("pusher_enabled")) {
                            $user = $device->getUser();
                            $where = $user->getIsAdmin() ? "" : " WHERE Message.userID = {$user->getID()}";
                            $query = "SELECT COUNT(IF(Message.status = 'Received', 1, NULL)) as totalReceived, deviceID FROM Message" . $where . " GROUP BY deviceID";
                            $counts = MysqliDb::getInstance()->rawQuery($query);
                            $result = sendPusherNotification("user-{$user->getApiKey()}", "messages-received", ["counts" => $counts, "messages" => $receivedMessages]);
                            if ($result["status"] != 200) {
                                error_log("Pusher result: " . json_encode($result));
                            }
                        }

                        if ($device->getUser()->getSmsToEmail()) {
                            $admin = User::getAdmin();
                            $from = array($admin->getEmail(), $admin->getName());
                            $to = [
                                $device->getUser()->getEmail(),
                                $device->getUser()->getName()
                            ];
                            foreach ($receivedMessages as $receivedMessage) {
                                Job::queue("sendEmail", [$from, $to, "Message from {$receivedMessage["number"]} on {$receivedMessage["device"]}{$receivedMessage["sim"]}", $receivedMessage["message"]]);
                            }
                        }
                    }
                } catch (Exception $e) {
                    error_log($e->getMessage());
                }
            }
            MysqliDb::getInstance()->commit();
            try {
                if (!empty($sendMessages)) {
                    Message::sendMessages($sendMessages, $device->getUser(), [$device->getID()]);
                }
            } catch (Exception $exception) {}
            if (!empty($device->getUser()->getWebHook())) {
                $client = new Client();
                $data = json_encode($messageObjects);
                $signature = base64_encode(hash_hmac('sha256', $data, $device->getUser()->getApiKey(), true));
                try {
                    $client->request('POST', $device->getUser()->getWebHook(), ['form_params' => ['messages' => $data], 'headers' => ['X-SG-Signature' => $signature], 'verify' => false]);
                } catch (GuzzleException $e) {
                    error_log($e->getMessage());
                }
            }
            echo json_encode(["success" => true, "data" => null, "error" => null]);
        } else {
            echo json_encode(["success" => false, "data" => null, "error" => ["code" => 401, "message" => __("error_device_not_found")]]);
        }
    } else {
        throw new Exception(__("error_invalid_request_format"));
    }
} catch (Exception $e) {
    echo json_encode(["success" => false, "data" => null, "error" => ["code" => 500, "message" => $e->getMessage()]]);
}

$time_end = microtime(true);
$execution_time = $time_end - $time_start;
//error_log("Total Execution Time: {$execution_time} seconds");